#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-3EG0jTPTC6VAOHeVaQOdsV
key:                  gitit-0.16-3EG0jTPTC6VAOHeVaQOdsV
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  5307b4a26b9bc645bc2f7e563105242f
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-3EG0jTPTC6VAOHeVaQOdsV
depends:
    HStringTemplate-0.8.8-IAaVZRSfZqwFVkbWmGYd3g
    HTTP-4000.5.0-6h2MaZL5UNn7CPY0IuQMdW
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    blaze-html-0.9.2.0-FHozDOQfWbTE40Bgc3es6n bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-JVCRff9KELenKRjYBPBwO
    feed-1.3.2.1-xIq8kVIcoie6LX7Yy6Lx filepath-1.4.300.1
    filestore-0.6.5.1-Fx1qJBquhrkDSJFU9uThW0 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-9Rjb5Ir8hHDIRzErqWDa8I
    hoauth2-2.14.0-CBj85czbuonIFONiniYUvO
    hslogger-1.3.2.0-D93Y2qjH7EfINBYoIXbCKD
    http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
    http-conduit-2.3.9.1-2GTRnba790eGqDwPWAtOWK
    json-0.11-JeW4hUw381UJtzGKB2KO9g mtl-2.3.1
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb
    network-bsd-2.8.1.0-LwcVYC1p0AwTZxC8Sb78E
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
    pandoc-3.6.1-A0xw7m9SHjA6Ws2Qavg7Fu
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6 parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    recaptcha-0.1.0.4-4KfH5iPZc0A6alZGBvH456
    safe-0.3.21-BwgmeaVWtgPGRp7BdJoWxU
    skylighting-0.14.5-Dx04r6CAlWS7nKy0YzdUv7
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1
    tagsoup-0.14.8-DWOmiJXtEgX7eE3Elrwm1T
    temporary-1.3-6LHFZ2D4FfEKQZFjyV7a7h text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-F70JT3mYIk5IGpwwoaGPAN
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-IOSNwAVvUqVFQ2c2QwOTYP xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-C84JdkwlC5a2lZXildVLnY
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-d9Z2UL1Q3oIQ3SIiNACha
    zlib-0.7.1.0-HgVwWopIY16LHV8ByRCkHf

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

